dSFMT: DSFMT_T Struct Reference

dSFMT 2.2

- Main Page
- Data Structures
- Files

- Data Structures
- Data Fields

Data Fields
DSFMT_T Struct Reference

the 128-bit internal state array More...

`#include <dSFMT.h>`

## Data Fields
w128_t | status [DSFMT_N+1]
int | idx

## Detailed Description

the 128-bit internal state array

## Field Documentation

int DSFMT_T::idx

Referenced by dsfmt_chk_init_by_array(), dsfmt_chk_init_gen_rand(), dsfmt_genrand_close1_open2(), and dsfmt_genrand_open_open().

w128_t DSFMT_T::status[DSFMT_N+1]

Referenced by dsfmt_chk_init_by_array(), dsfmt_chk_init_gen_rand(), dsfmt_gen_rand_all(), dsfmt_genrand_close1_open2(), dsfmt_genrand_open_open(), gen_rand_array_c0o1(), gen_rand_array_c1o2(), gen_rand_array_o0c1(), gen_rand_array_o0o1(), initial_mask(), and period_certification().

The documentation for this struct was generated from the following file:

- dSFMT.h